@@ -1,68 +1,11 @@
-/* $Id: gscanbus.c,v 1.19 2001/07/11 10:53:51 ami Exp $
+/*
+ * This file is part of the gscanbus project.
+ * Copyright (C) 2001  Andreas Micklei  <nurgle@gmx.de>
+ * Copyright (C) 2010  Gareth McMullin  <gareth@blacksphere.co.nz>
  *
  * gscanbus.c - Linux IEEE-1394 Subsystem GDK Topology Viewing utility
- * version 0.1:	initial release
- * 		written 18.11.1999 by Andreas Micklei <micklei@fokus.gmd.de>
- * version 0.2: GUI Improvements: dubble buffering, highlighting of host
- *              Moved rominfo routines into a seperate file
- *              Added node information dialog
- *              Added guid-resolv.conf configuration file
- *              Various code cleanups and comments
- * 		written 22.11.1999 by Andreas Micklei <micklei@fokus.gmd.de>
- * version 0.3: Adapted to new libraw1394 by Andreas E. Bombe
- * 		included custom function for getting the topology map
- * 		added simpleavc to control DVCRS and Camcorders, that conform
- * 		to the VCR subunit specification
- * 		written 10.12.1999 by Andreas Micklei <micklei@fokus.gmd.de>
- * version 0.4: new, much more flexible simpleavc (still simple though ;-))
- * 		Included some infos from rom_info into popup dialogs
- * 		Added Menu Bar with Menu items analogous to gnome1394
- * 		written 03.02.2000 by Andreas Micklei <micklei@fokus.gmd.de>
- * version 0.5: Moved menue bar and dialogs to menues.c
- *		Added read Block Transaction from gnome1394
- *		Incorporated endianess changes (Simon Vogl)
- *		Adapted simpleavc to new FCP handling of libraw1394 0.6
- *		written 06.04.2000 by Andreas Micklei
- *		<andreas.micklei@ivistar.de>
- * version 0.6: Added AV/C subunit detection
- * 		Added VCR status display
- * 		Fixed Black-Window bug (Thanks to Mark Knecht for reporting)
- * 		Added various new constants and functions to simpleavc
- * 		Fixed simpleavc block transactions
- * 		Pixmaps are now compiled in
- *		written 22.05.2000 by Andreas Micklei
- *		<andreas.micklei@ivistar.de>
- * version 0.7-pre1:
- *		Added initial support for >=4 port phys (display is not yet
- *		correct)
- *		Added support for slow units via delay in rom_info
- *		Switched to cooked functions from raw1394util. This supercedes
- *		the delay calls. The necessary data field is left in however
- *		for further experiments.
- * version 0.7-pre2:
- *		Adapted error handling code to new semantics of libraw1394
- *		written 26.01.2001 by Andreas Micklei
- *		<andreas.micklei@ivistar.de>
- *
- * version 0.7:
- *		Stabilization
- *		Recognition of more devices (Windows and MacOS PCs for
- *		example) and more icons
- *		written 05.06.2001 by Andreas Micklei
- *		<andreas.micklei@ivistar.de>
- *
- * version 0.7.1:
- *		Incorporated major bugfixes from Manfred Weihs: Delay is no
- *		longer used at all (was used unitialized before).
- *		Incorporated patch from Jim Harkins: ASCII dump in block read
- *		dialog, fixed some compiler warnings.
- *
- * 		TODO:
- * 		- Improve Layout of Block Transactions
- * 		- Implement Block and Lock Transactions
- * 		- Implement more Control Functions
- * 		- Implement rendering for >=4 port phys
- * 		- Remove SIGSEGV crashes
+ * 		written 18.11.1999 to 05.06.2001 by Andreas Micklei 
+ * 		updated for GTK+ 2 by Gareth McMullin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -110,12 +53,12 @@ int repaintCountdown = 0;
 static GdkPixmap *pixmap = NULL;
 
 const char not_compatible[] = "\
-This libraw1394 does not work with your version of Linux. You need a different
-version that matches your kernel (see kernel help text for the raw1394 option to
+This libraw1394 does not work with your version of Linux. You need a different\
+version that matches your kernel (see kernel help text for the raw1394 option to\
 find out which is the correct version).\n";
 
 const char not_loaded[] = "\
-This probably means that you don't have raw1394 support in the kernel or that
+This probably means that you don't have raw1394 support in the kernel or that\
 you haven't loaded the raw1394 module.\n";
 
 /*---------------------------------------------------------------------------
@@ -136,8 +79,9 @@ you haven't loaded the raw1394 module.\n";
  * 	col_old:	The color to restore when finished
  */
 void drawTopologyLine(GdkDrawable *drawable, GdkGC *gc,
-	int x1, int y1, int x2, int y2, TopologyTree *node,
-	TopologyTree *child, GdkColor *col_new, GdkColor *col_old) {
+		int x1, int y1, int x2, int y2, TopologyTree *node,
+		TopologyTree *child, GdkColor *col_new, GdkColor *col_old) 
+{
 	SETLINEWIDTH(gc,(MIN(node->selfid[0].packetZero.phySpeed,
 		child->selfid[0].packetZero.phySpeed)+1)*2);
 	gdk_gc_set_foreground(gc, col_new);
@@ -145,8 +89,8 @@ void drawTopologyLine(GdkDrawable *drawable, GdkGC *gc,
 	gdk_gc_set_foreground(gc, col_old);
 }
 
-void chooseLabel(Rom_info *rom_info, TopologyTree *node, char *label) {
-
+void chooseLabel(Rom_info *rom_info, TopologyTree *node, char *label) 
+{
 	/* Use rom_info->label if it contains something meaningful */
 	if (rom_info->label != NULL && strcmp(rom_info->label, "Unknown")) {
 		strcpy(node->label, rom_info->label);
@@ -171,7 +115,8 @@ void chooseLabel(Rom_info *rom_info, TopologyTree *node, char *label) {
  * 	level:		depth of the current subTree in respect to the root
  */
 void drawTopologyTree(GdkDrawable *drawable, GdkWindow *window, GdkGC *gc,
-    	TopologyTree *node, int myPhyID, int left, int width, int level) {
+	    	TopologyTree *node, int myPhyID, int left, int width, int level) 
+{
     	int nodewidth = NODEWIDTH;
     	int nodeheight = NODEHEIGHT;
 	int xpmwidth;
@@ -294,12 +239,12 @@ void drawTopologyTree(GdkDrawable *drawable, GdkWindow *window, GdkGC *gc,
 	/* Draw icon */
 	gdk_gc_set_foreground(gc, &gc_values.foreground);
 
-	gdk_window_get_size(xpm_node, &xpmwidth, &xpmheight);
+	gdk_drawable_get_size(GDK_DRAWABLE(xpm_node), &xpmwidth, &xpmheight);
 
 	gdk_gc_set_clip_origin(gc, left + (width/2 - xpmwidth/2),
 		level*nodeheight*2 + (nodeheight-xpmheight)/2);
 	gdk_gc_set_clip_mask(gc, xpm_node_mask);
-	gdk_draw_pixmap(drawable, gc, xpm_node, 0, 0,
+	gdk_draw_drawable(drawable, gc, xpm_node, 0, 0,
 		left + (width/2 - xpmwidth/2),
 		level*nodeheight*2 + (nodeheight-xpmheight)/2,
 		xpmwidth, xpmheight);
@@ -323,7 +268,8 @@ void drawTopologyTree(GdkDrawable *drawable, GdkWindow *window, GdkGC *gc,
  * IN:		data:	A pointer to the drawable of the main window
  * RESULT:	TRUE on success, FALSE otherwise
  */
-gint Repaint (gpointer data) {
+gint Repaint (gpointer data) 
+{
 	RAW1394topologyMap* topologyMap;
 	int nodeCount, depth;
 	GtkWidget* drawing_area = (GtkWidget *) data;
@@ -385,7 +331,8 @@ gint Repaint (gpointer data) {
  * RESULT:	clicked node or NULL if no node was clicked
  */
 TopologyTree *detectClick(TopologyTree *node, int left, int width, int level,
-	int x, int y) {
+			int x, int y) 
+{
     	TopologyTree *child;
 	TopologyTree *click;
 
@@ -434,10 +381,11 @@ TopologyTree *detectClick(TopologyTree *node, int left, int width, int level,
  * 		event:	the expose event
  * RESULT:	always FALSE
  */
-static gint expose_event(GtkWidget *widget, GdkEventExpose *event) {
-	gdk_draw_pixmap(widget->window,
+static gint expose_event(GtkWidget *widget, GdkEventExpose *event) 
+{
+	gdk_draw_drawable(widget->window,
 		widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
-		pixmap,
+		GDK_DRAWABLE(pixmap),
 		event->area.x, event->area.y,
 		event->area.x, event->area.y,
 		event->area.width, event->area.height);
@@ -451,9 +399,10 @@ static gint expose_event(GtkWidget *widget, GdkEventExpose *event) {
  * 		event:	the configure event
  * RESULT:	always TRUE
  */
-static gint configure_event(GtkWidget *widget, GdkEventConfigure *event) {
+static gint configure_event(GtkWidget *widget, GdkEventConfigure *event) 
+{
 	if (pixmap) {
-		gdk_pixmap_unref(pixmap);
+		g_object_unref(pixmap);
 	}
 
 	pixmap = gdk_pixmap_new(widget->window,
@@ -466,26 +415,6 @@ static gint configure_event(GtkWidget *widget, GdkEventConfigure *event) {
 	return TRUE;
 }
 
-/* The following are now defined in menues.c */
-#if 0
-/*
- * Closes a dialog window.
- * IN:		widget:	not used
- * 		data:	the dialog
- */
-void CloseDialog(GtkWidget *widget, gpointer data) {
-	gtk_widget_destroy(GTK_WIDGET(data));
-}
-
-/*
- * Called when a dialog is closing. Releases the input focus.
- * IN:		widget:	the dialog
- */
-void ClosingDialog(GtkWidget *widget, gpointer data) {
-	gtk_grab_remove(GTK_WIDGET(widget));
-}
-#endif
-
 #define AVC_RETRY 4
 #define CTLVCR0 AVC_CTYPE_CONTROL | AVC_SUBUNIT_TYPE_TAPE_RECORDER | AVC_SUBUNIT_ID_0
 #define STATVCR0 AVC_CTYPE_STATUS | AVC_SUBUNIT_TYPE_TAPE_RECORDER | AVC_SUBUNIT_ID_0
@@ -501,7 +430,8 @@ void ClosingDialog(GtkWidget *widget, gpointer data) {
  * RETURNS:	OPERAND if device is playing
  * 		0 otherwise
  */
-int isPlaying(raw1394handle_t handle, int phyID) {
+int isPlaying(raw1394handle_t handle, int phyID)
+{
 	quadlet_t response = avc_transaction(handle, phyID, STATVCR0
 		| VCR_COMMAND_TRANSPORT_STATE | VCR_OPERAND_TRANSPORT_STATE,
 		AVC_RETRY);
@@ -519,7 +449,8 @@ int isPlaying(raw1394handle_t handle, int phyID) {
  * RETURNS:	OPERAND if device is recording
  * 		0 otherwise
  */
-int isRecording(raw1394handle_t handle, int phyID) {
+int isRecording(raw1394handle_t handle, int phyID)
+{
 	quadlet_t response = avc_transaction(handle, phyID, STATVCR0
 		| VCR_COMMAND_TRANSPORT_STATE | VCR_OPERAND_TRANSPORT_STATE,
                 AVC_RETRY);
@@ -537,7 +468,8 @@ int isRecording(raw1394handle_t handle, int phyID) {
  * IN:		widget:	the button
  * 		data:	The node
  */
-void avc_play(GtkWidget *widget, gpointer data) {
+void avc_play(GtkWidget *widget, gpointer data)
+{
 	int phyID;
 
 	phyID = ((TopologyTree *)data)->selfid[0].packetZero.phyID;
@@ -555,7 +487,8 @@ void avc_play(GtkWidget *widget, gpointer data) {
  * IN:		widget:	the button
  * 		data:	The node
  */
-void avc_stop(GtkWidget *widget, gpointer data) {
+void avc_stop(GtkWidget *widget, gpointer data)
+{
 	int phyID;
 
 	phyID = ((TopologyTree *)data)->selfid[0].packetZero.phyID;
@@ -571,7 +504,8 @@ void avc_stop(GtkWidget *widget, gpointer data) {
  * IN:		widget:	the button
  * 		data:	The node
  */
-void avc_rewind(GtkWidget *widget, gpointer data) {
+void avc_rewind(GtkWidget *widget, gpointer data) 
+{
 	int phyID;
 
 	phyID = ((TopologyTree *)data)->selfid[0].packetZero.phyID;
@@ -591,7 +525,8 @@ void avc_rewind(GtkWidget *widget, gpointer data) {
  * IN:		widget:	the button
  * 		data:	The node
  */
-void avc_pause(GtkWidget *widget, gpointer data) {
+void avc_pause(GtkWidget *widget, gpointer data) 
+{
 	int phyID, mode;
 
 	phyID = ((TopologyTree *)data)->selfid[0].packetZero.phyID;
@@ -623,7 +558,8 @@ void avc_pause(GtkWidget *widget, gpointer data) {
  * IN:		widget:	the button
  * 		data:	The node
  */
-void avc_forward(GtkWidget *widget, gpointer data) {
+void avc_forward(GtkWidget *widget, gpointer data) 
+{
 	int phyID;
 
 	phyID = ((TopologyTree *)data)->selfid[0].packetZero.phyID;
@@ -642,7 +578,8 @@ void avc_forward(GtkWidget *widget, gpointer data) {
  * IN:		widget:	the button
  * 		data:	The node
  */
-void avc_eject(GtkWidget *widget, gpointer data) {
+void avc_eject(GtkWidget *widget, gpointer data) 
+{
 	int phyID;
 
 	phyID = ((TopologyTree *)data)->selfid[0].packetZero.phyID;
@@ -655,7 +592,8 @@ void avc_eject(GtkWidget *widget, gpointer data) {
  * IN:		widget:	the button
  * 		data:	The node
  */
-void avc_record(GtkWidget *widget, gpointer data) {
+void avc_record(GtkWidget *widget, gpointer data) 
+{
 	int phyID;
 
 	phyID = ((TopologyTree *)data)->selfid[0].packetZero.phyID;
@@ -665,7 +603,8 @@ void avc_record(GtkWidget *widget, gpointer data) {
 
 #define MAX_DESCRIPTORS 0x100
 void avc_test_descriptors(int phyID, quadlet_t subunit_type,
-	quadlet_t subunit_id) {
+			quadlet_t subunit_id) 
+{
 	int i;
 	quadlet_t response;
 	char descriptors[MAX_DESCRIPTORS];
@@ -693,7 +632,8 @@ struct status_entry {
 	GtkWidget *entry;
 };
 
-gint update_avc_status(gpointer data) {
+gint update_avc_status(gpointer data) 
+{
 	struct status_entry *status_entry = (struct status_entry *) data;
 	char *status;
 	int phyID;
@@ -712,71 +652,58 @@ gint update_avc_status(gpointer data) {
 	return TRUE;
 }
 
-GtkWidget *make_avc_buttons(TopologyTree *node) {
-	//GtkWidget *table, *button;
+GtkWidget *make_avc_buttons(TopologyTree *node) 
+{
 	GtkWidget *hbox1, *hbox2, *hbox3, *vbox, *button, *label, *entry;
 	struct status_entry *status_entry;
 
 	status_entry = malloc(sizeof(struct status_entry));
 	if (status_entry == NULL) fatal("out of memory");
 
-	//table = gtk_table_new(8, 2, FALSE);
 	hbox1 = gtk_hbox_new(TRUE, 0);
 	hbox2 = gtk_hbox_new(TRUE, 0);
 	hbox3 = gtk_hbox_new(FALSE, 0);
 	button = gtk_button_new_with_label("<<");
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		GTK_SIGNAL_FUNC(avc_rewind), node);
+	g_signal_connect(GTK_OBJECT(button), "clicked",
+		G_CALLBACK(avc_rewind), node);
 	gtk_widget_show(button);
-	//gtk_table_attach_defaults(GTK_TABLE(table), button, 1, 3, 0, 1);
 	gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 0);
 	button = gtk_button_new_with_label("PLAY");
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		GTK_SIGNAL_FUNC(avc_play), node);
+	g_signal_connect(GTK_OBJECT(button), "clicked",
+		G_CALLBACK(avc_play), node);
 	gtk_widget_show(button);
-	//gtk_table_attach_defaults(GTK_TABLE(table), button, 3, 5, 0, 1);
 	gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 0);
 	button = gtk_button_new_with_label(">>");
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		GTK_SIGNAL_FUNC(avc_forward), node);
+	g_signal_connect(GTK_OBJECT(button), "clicked",
+		G_CALLBACK(avc_forward), node);
 	gtk_widget_show(button);
-	//gtk_table_attach_defaults(GTK_TABLE(table), button, 5, 7, 0, 1);
 	gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 0);
 	button = gtk_button_new_with_label("STOP");
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		GTK_SIGNAL_FUNC(avc_stop), node);
+	g_signal_connect(GTK_OBJECT(button), "clicked",
+		G_CALLBACK(avc_stop), node);
 	gtk_widget_show(button);
-	//gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 2, 1, 2);
 	gtk_box_pack_start(GTK_BOX(hbox2), button, TRUE, TRUE, 0);
 	button = gtk_button_new_with_label("||");
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		GTK_SIGNAL_FUNC(avc_pause), node);
+	g_signal_connect(GTK_OBJECT(button), "clicked",
+		G_CALLBACK(avc_pause), node);
 	gtk_widget_show(button);
-	//gtk_table_attach_defaults(GTK_TABLE(table), button, 2, 4, 1, 2);
 	gtk_box_pack_start(GTK_BOX(hbox2), button, TRUE, TRUE, 0);
 	button = gtk_button_new_with_label("Eject");
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		GTK_SIGNAL_FUNC(avc_eject), node);
+	g_signal_connect(GTK_OBJECT(button), "clicked",
+		G_CALLBACK(avc_eject), node);
 	gtk_widget_show(button);
-	//gtk_table_attach_defaults(GTK_TABLE(table), button, 4, 6, 1, 2);
 	gtk_box_pack_start(GTK_BOX(hbox2), button, TRUE, TRUE, 0);
 	button = gtk_button_new_with_label("Record");
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		GTK_SIGNAL_FUNC(avc_record), node);
+	g_signal_connect(GTK_OBJECT(button), "clicked",
+		G_CALLBACK(avc_record), node);
 	gtk_widget_show(button);
-	//gtk_table_attach_defaults(GTK_TABLE(table), button, 6, 8, 1, 2);
 	gtk_box_pack_start(GTK_BOX(hbox2), button, TRUE, TRUE, 0);
-	//gtk_widget_show(table);
-	//return table;
 
 	label = gtk_label_new("Status: ");
 	gtk_widget_show(label);
 	entry = gtk_entry_new();
-	gtk_entry_set_editable(GTK_ENTRY(entry), FALSE);
-	//gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		//GTK_SIGNAL_FUNC(avc_record), node);
+	gtk_editable_set_editable(GTK_EDITABLE(entry), FALSE);
 	gtk_widget_show(entry);
-	//gtk_table_attach_defaults(GTK_TABLE(table), button, 6, 8, 1, 2);
 	gtk_box_pack_start(GTK_BOX(hbox3), label, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox3), entry, TRUE, TRUE, 0);
 
@@ -792,7 +719,7 @@ GtkWidget *make_avc_buttons(TopologyTree *node) {
 	status_entry->node = node;
 	status_entry->entry = entry;
 
-	gtk_timeout_add(500, update_avc_status, status_entry);
+	g_timeout_add(500, update_avc_status, status_entry);
 
 	return vbox;
 }
@@ -858,24 +785,23 @@ void append_subunit_strings(char *buf, quadlet_t table[8]) {
  * IN:		node: The node to display information about
  */
 void popup_nodeinfo(TopologyTree *node) {
-	GtkWidget *button, *dialog_window, *hbox, *text, *scrollbar;
-	//char s[1000];	/* FIXME */
-	char s[10000];	/* FIXME */
+	GtkWidget *button, *dialog_window, *hbox, *text, *sw;
+	char *s;
 	char textualleafes[MAXTEXTLEAFCHARS];
 	int nchars, nleafes, i;
 	quadlet_t table[8];
 	char avcstring[MAXAVCSTRINGCHARS];
 
 	dialog_window = gtk_dialog_new();
-	gtk_signal_connect(GTK_OBJECT(dialog_window), "destroy",
-		GTK_SIGNAL_FUNC(ClosingDialog),
+	g_signal_connect(GTK_OBJECT(dialog_window), "destroy",
+		G_CALLBACK(ClosingDialog),
 		&dialog_window);
 	if (node->label != NULL && node->label[0] != '\0') {
 		gtk_window_set_title(GTK_WINDOW(dialog_window),
 		node->label);
 	} else
 		gtk_window_set_title(GTK_WINDOW(dialog_window), "Node Info");
-	gtk_container_border_width(GTK_CONTAINER(dialog_window), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(dialog_window), 5);
 	/*gtk_window_set_default_size(GTK_WINDOW(dialog_window), 300, 250);*/
 	gtk_window_set_default_size(GTK_WINDOW(dialog_window), 300, 300);
 
@@ -905,7 +831,7 @@ void popup_nodeinfo(TopologyTree *node) {
 	DEBUG_GENERAL fprintf(stderr,"Got AVC subunit info\n");
 
 	//sprintf(s, "SelfID Info\n-----------\nPhysical ID: %i\nLink active: %s\nGap Count: %i\nPHY Speed: %s\nPHY Delay: %s\nIRM Capable: %s\nPower Class: %s\nPort 0: %s\nPort 1: %s\nPort 2: %s\nInit. reset: %s\n\nCSR ROM Info\n------------\nGUID: 0x%08X%08X\nNode Capabilities: 0x%08X\nVendor ID: 0x%08X\nUnit Spec ID: 0x%08X\nUnit SW Version: 0x%08X\nModel ID: 0x%08X\nNr. Textual Leafes: %i\n\nTextual Leafes: %s\n\nAV/C Subunits\n-------------\n%s",
-	sprintf(s, "SelfID Info\n-----------\nPhysical ID: %i\nLink active: %s\nGap Count: %i\nPHY Speed: %s\nPHY Delay: %s\nIRM Capable: %s\nPower Class: %s\n%sInit. reset: %s\n\nCSR ROM Info\n------------\nGUID: 0x%08X%08X\nNode Capabilities: 0x%08X\nVendor ID: 0x%08X\nUnit Spec ID: 0x%08X\nUnit SW Version: 0x%08X\nModel ID: 0x%08X\nNr. Textual Leafes: %i\n\nVendor: %s\nTextual Leafes: %s\n\nAV/C Subunits\n-------------\n%s",
+	s = g_strdup_printf("SelfID Info\n-----------\nPhysical ID: %i\nLink active: %s\nGap Count: %i\nPHY Speed: %s\nPHY Delay: %s\nIRM Capable: %s\nPower Class: %s\n%sInit. reset: %s\n\nCSR ROM Info\n------------\nGUID: 0x%08X%08X\nNode Capabilities: 0x%08X\nVendor ID: 0x%08X\nUnit Spec ID: 0x%08X\nUnit SW Version: 0x%08X\nModel ID: 0x%08X\nNr. Textual Leafes: %i\n\nVendor: %s\nTextual Leafes: %s\n\nAV/C Subunits\n-------------\n%s",
 		node->selfid[0].packetZero.phyID,
 		yes_no(node->selfid[0].packetZero.linkActive),
 		node->selfid[0].packetZero.gapCount,
@@ -929,21 +855,16 @@ void popup_nodeinfo(TopologyTree *node) {
 		textualleafes,
 		avcstring);
 
-	text = gtk_text_new(NULL, NULL);
-	gtk_text_set_editable(GTK_TEXT(text), FALSE);
-	gtk_text_insert(GTK_TEXT(text), NULL, NULL, NULL, s, strlen(s));
-	gtk_widget_show(text);
+	text = gtk_text_view_new();
+	gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
+	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text)), s, -1);
+	g_free(s);
 
-	scrollbar = gtk_vscrollbar_new(GTK_TEXT(text)->vadj);
-	gtk_widget_show(scrollbar);
-
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(hbox), text, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(hbox), scrollbar, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
+	sw = gtk_scrolled_window_new(NULL, NULL);
+	gtk_container_add(GTK_CONTAINER(sw), text);
 
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog_window)->vbox),
-		hbox, TRUE, TRUE, 0);
+		sw, TRUE, TRUE, 0);
 
 	if (get_node_type(&node->rom_info) == NODE_TYPE_AVC) {
 		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog_window)->vbox),
@@ -951,8 +872,8 @@ void popup_nodeinfo(TopologyTree *node) {
 	}
 
 	button = gtk_button_new_with_label("OK");
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		GTK_SIGNAL_FUNC(CloseDialog),
+	g_signal_connect(GTK_OBJECT(button), "clicked",
+		G_CALLBACK(CloseDialog),
 		dialog_window);
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog_window)->action_area),
@@ -960,7 +881,7 @@ void popup_nodeinfo(TopologyTree *node) {
 	gtk_widget_grab_default(button);
 	gtk_widget_show(button);
 
-	gtk_widget_show(dialog_window);
+	gtk_widget_show_all(dialog_window);
 }
 
 /*
@@ -979,7 +900,7 @@ static gint button_press_event(GtkWidget *widget, GdkEventButton *event) {
 		x = event->x;
 		y = event->y;
 		state = event->state;
-		gdk_window_get_size(event->window, &width, &height);
+		gdk_drawable_get_size(GDK_DRAWABLE(event->window), &width, &height);
 		node = detectClick(topologyTree, 0, width, 0, x, y);
 		if (node != NULL) {
 			popup_nodeinfo(node);
@@ -988,13 +909,6 @@ static gint button_press_event(GtkWidget *widget, GdkEventButton *event) {
 	return TRUE;
 }
 
-/*
- * Called when the application exits. All cleanup code should go here.
- */
-void quit () {
-	gtk_exit (0);
-}
-
 /*
  * Called whenever a bus reset has occured before the last read was startet.
  * Calls Repaint().
@@ -1037,14 +951,14 @@ GtkWidget *makeDrawingArea(int x, int y) {
 	GtkWidget *drawing_area;
 
 	drawing_area = gtk_drawing_area_new ();
-	gtk_drawing_area_size (GTK_DRAWING_AREA (drawing_area), x, y);
+	gtk_widget_set_size_request(GTK_WIDGET(drawing_area), x, y);
 	gtk_widget_show (drawing_area);
-	gtk_signal_connect (GTK_OBJECT (drawing_area), "expose_event",
-		GTK_SIGNAL_FUNC (expose_event), NULL);
-	gtk_signal_connect (GTK_OBJECT (drawing_area), "configure_event",
-		GTK_SIGNAL_FUNC (configure_event), NULL);
-	gtk_signal_connect (GTK_OBJECT (drawing_area), "button_press_event",
-		GTK_SIGNAL_FUNC (button_press_event), NULL);
+	g_signal_connect (GTK_OBJECT (drawing_area), "expose_event",
+		G_CALLBACK (expose_event), NULL);
+	g_signal_connect (GTK_OBJECT (drawing_area), "configure_event",
+		G_CALLBACK (configure_event), NULL);
+	g_signal_connect (GTK_OBJECT (drawing_area), "button_press_event",
+		G_CALLBACK (button_press_event), NULL);
 	gtk_widget_set_events(drawing_area, GDK_EXPOSURE_MASK
 		| GDK_LEAVE_NOTIFY_MASK
 		| GDK_BUTTON_PRESS_MASK);
@@ -1062,9 +976,9 @@ int main (int argc, char *argv[])
 	GtkWidget *menu_bar;
 	quadlet_t quadlet;
 	int c, level;
-
+	int port = 0;
 	/* Parse command line options */
-	const char *optstring = "v::";
+	const char *optstring = "p:v::";
 
 	do {
 		c = getopt(argc, argv, optstring);
@@ -1075,6 +989,10 @@ int main (int argc, char *argv[])
 				fprintf(stderr, "Debug level: %i\n", level);
 				set_debug_level(level);
 				break;
+ 		        case 'p':
+			        if (optarg == NULL) port = 0;
+				else port = atoi(optarg);
+	 
 		}
 	} while (c != -1);
 
@@ -1094,9 +1012,9 @@ int main (int argc, char *argv[])
         DEBUG_GENERAL fprintf(stderr, "successfully got handle\n");
         DEBUG_GENERAL fprintf(stderr, "current generation number: %d\n",
 		raw1394_get_generation(handle));
-	if (raw1394_set_port(handle, 0) < 0) {
+	if (raw1394_set_port(handle, port) < 0) {
 		perror("couldn't set port");
-		exit(1);
+		//exit(1);
 	}
 
 	DEBUG_GENERAL fprintf(stderr,"using first card found: %d nodes on bus, local ID is %d\n",
@@ -1115,9 +1033,8 @@ int main (int argc, char *argv[])
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (window), vbox);
-	gtk_widget_show (vbox);
-	gtk_signal_connect (GTK_OBJECT (window), "destroy",
-		GTK_SIGNAL_FUNC (quit), NULL);
+	g_signal_connect (GTK_OBJECT (window), "destroy",
+		G_CALLBACK (gtk_main_quit), NULL);
 
 	menu_bar = makeMenuBar(window);
 	drawing_area = makeDrawingArea(640, 480);
@@ -1125,10 +1042,9 @@ int main (int argc, char *argv[])
 	gtk_box_pack_start (GTK_BOX (vbox), menu_bar, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), drawing_area, TRUE, TRUE, 0);
 
-	gtk_widget_show (window);
+	gtk_widget_show_all (window);
 	Repaint((gpointer) drawing_area);
-	gtk_timeout_add(100, dummy_read, NULL);
-	//gtk_idle_add( dummy_read, NULL );
+	g_timeout_add(100, dummy_read, NULL);
 
 	gtk_main ();	/* Should never return */
 
