@@ -1,4 +1,6 @@
-/* $Id: rominfo.c,v 1.15 2001/07/11 10:53:51 ami Exp $
+/* 
+ * This file is part of the gscanbus project.
+ * Copyright (C) 2001  Andreas Micklei  <nurgle@gmx.de>
  *
  * rominfo.c - Linux IEEE-1394 Subsystem CSR ROM info reading routines
  * written 23.11.1999 - 24.11. 1999 by Andreas Micklei
@@ -22,10 +24,10 @@
 #include <netinet/in.h>
 #define MAXLINE 80
 #define GUIDFILENAME0 "guid-resolv.conf"
-#define GUIDFILENAME1 "/etc/guid-resolv.conf"
+#define GUIDFILENAME1 SYSCONFDIR "/guid-resolv.conf"
 #define GUIDERROR "Error while opening guid-resolv.conf"
 #define OUIFILENAME0 "oui-resolv.conf"
-#define OUIFILENAME1 "/etc/oui-resolv.conf"
+#define OUIFILENAME1 SYSCONFDIR "/oui-resolv.conf"
 #define OUIERROR "Error while opening oui-resolv.conf"
 
 #define QUADINC(x) x = x + 4
@@ -258,7 +260,9 @@ char *resolv_oui(int oui) {
 int get_node_type(Rom_info *rom_info) {
 	char cpu;
 	if (rom_info->unit_spec_id == 0xA02D) {
-		if (rom_info->unit_sw_version == 0x100) {
+		if ((rom_info->unit_sw_version == 0x100)||
+		(rom_info->unit_sw_version == 0x101) ||
+		(rom_info->unit_sw_version == 0x102)) {
 			return NODE_TYPE_CONF_CAM;
 		} else if (rom_info->unit_sw_version == 0x10000 ||
 			rom_info->unit_sw_version == 0x10001) {
